==> loadmychunks-1.2.0%2B1.16.5%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/block/BlockLagometer.java <==
package com.drathonix.loadmychunks.common.block;


import com.mojang.serialization.MapCodec;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2464;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2758;
import net.minecraft.class_3218;
import com.drathonix.loadmychunks.common.block.blockentity.BlockEntityLagometer;
import com.drathonix.loadmychunks.common.system.ChunkDataManager;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class BlockLagometer extends class_2237 {
    //? if >1.20.3 {
    /*public static final MapCodec<BlockLagometer> CODEC = simpleCodec(BlockLagometer::new);
    @Override
    protected MapCodec<? extends BaseEntityBlock> codec() {
        return CODEC;
    }
    *///?}
    public static final class_2758 LAG = class_2758.method_11867("lmc_lag",0,15);


    public BlockLagometer(class_2251 properties) {
        super(properties);
        method_9590(this.field_10647.method_11664().method_11657(LAG, 0));
    }



    @Override
    public @NotNull class_2464 method_9604(class_2680 blockState) {
        return class_2464.field_11458;
    }

    //? if <=1.16.5 {
    @Nullable
    @Override
    public class_2586 method_10123(class_1922 blockGetter) {
        return new BlockEntityLagometer();
    }
    //?}

    //? if >1.16.5 {
    /*@Nullable
    @Override
    public BlockEntity newBlockEntity(BlockPos blockPos, BlockState blockState) {
        return new BlockEntityLagometer(blockPos,blockState);
    }
    *///?}

    @Override
    public boolean method_9498(class_2680 blockState) {
        return true;
    }

    @Override
    public int method_9572(class_2680 blockState, class_1937 level, class_2338 blockPos) {
        if(level instanceof class_3218) {
            return (int) (ChunkDataManager.getOrCreateChunkData((class_3218)level, blockPos).getTickTimer().getLagFraction()*15.0);
        }
        return 0;
    }

    protected void method_9515(class_2689.class_2690<class_2248, class_2680> arg) {
        arg.method_11667(LAG);
    }
}

==> loadmychunks-1.2.1%2B1.19.2%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/block/BlockLagometer.java <==
package com.drathonix.loadmychunks.common.block;


import com.mojang.serialization.MapCodec;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2464;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2758;
import net.minecraft.class_3218;
import com.drathonix.loadmychunks.common.block.blockentity.BlockEntityLagometer;
import com.drathonix.loadmychunks.common.system.ChunkDataManager;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class BlockLagometer extends class_2237 {
    //? if >1.20.3 {
    /*public static final MapCodec<BlockLagometer> CODEC = simpleCodec(BlockLagometer::new);
    @Override
    protected MapCodec<? extends BaseEntityBlock> codec() {
        return CODEC;
    }
    *///?}
    public static final class_2758 LAG = class_2758.method_11867("lmc_lag",0,15);


    public BlockLagometer(class_2251 properties) {
        super(properties);
        method_9590(this.field_10647.method_11664().method_11657(LAG, 0));
    }



    @Override
    public @NotNull class_2464 method_9604(class_2680 blockState) {
        return class_2464.field_11458;
    }

    //? if <=1.16.5 {
    /*@Nullable
    @Override
    public BlockEntity newBlockEntity(BlockGetter blockGetter) {
        return new BlockEntityLagometer();
    }
    *///?}

    //? if >1.16.5 {
    @Nullable
    @Override
    public class_2586 method_10123(class_2338 blockPos, class_2680 blockState) {
        return new BlockEntityLagometer(blockPos,blockState);
    }
    //?}

    @Override
    public boolean method_9498(class_2680 blockState) {
        return true;
    }

    @Override
    public int method_9572(class_2680 blockState, class_1937 level, class_2338 blockPos) {
        if(level instanceof class_3218) {
            return (int) (ChunkDataManager.getOrCreateChunkData((class_3218)level, blockPos).getTickTimer().getLagFraction()*15.0);
        }
        return 0;
    }

    protected void method_9515(class_2689.class_2690<class_2248, class_2680> arg) {
        arg.method_11667(LAG);
    }
}
